BaseOutputParser

Trait BaseOutputParser 

pub trait BaseOutputParser<Input: Send + Sync + 'static, Output: Send + Sync + 'static>:
    Runnable<Input, Output>
    + Send
    + Sync {
    // Required method
    fn parse<'life0, 'async_trait>(
        &'life0 self,
        input: Input,
    ) -> Pin<Box<dyn Future<Output = Result<Output, WesichainError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Trait for output parsers that can transform input into a specific output. This is a specialized version of Runnable for parsing logic.

Required Methods

fn parse<'life0, 'async_trait>( &'life0 self, input: Input, ) -> Pin<Box<dyn Future<Output = Result<Output, WesichainError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Implementors